/*
 * Project name:
     Piezo_buzzer (Usage of Sound library)
 * Copyright:
     (c) mikroElektronika, 2011.
 * Revision History:
     20110202:
       - Initial release (SZ);
 * Description:
     This project is a simple demonstration of how to
     use sound library for playing tones on a piezo speaker.
 * Test configuration:
     MCU:             PIC24FJ16KA102
                      http://ww1.microchip.com/downloads/en/DeviceDoc/PIC24F16KA102_Family_datasheet_39927b.pdf
     Dev.Board:       Easy24-33 v6
                      http://www.mikroe.com/eng/products/view/494/easy24-33-v6-development-system/
     Oscillator:      HS, 8.00000 MHz
     Ext. Modules:    None.
     SW:              mikroC PRO for dsPIC30/33 and PIC24
                      http://www.mikroe.com/en/compilers/mikroc/pro/dspic/
 * NOTES:
     - Put button jumper (J17) into VCC position and
       pull-down pins RB7...RB3 on PORTB. (board specific)
     - J16 - RB8
*/


void Tone1() {
  Sound_Play(659, 250);   // Frequency = 659Hz, duration = 250ms
}

void Tone2() {
  Sound_Play(698, 250);   // Frequency = 698Hz, duration = 250ms
}

void Tone3() {
  Sound_Play(784, 250);   // Frequency = 784Hz, duration = 250ms
}

void Melody() {           // Plays the melody "Yellow house"
  Tone1(); Tone2(); Tone3(); Tone3();
  Tone1(); Tone2(); Tone3(); Tone3();
  Tone1(); Tone2(); Tone3();
  Tone1(); Tone2(); Tone3(); Tone3();
  Tone1(); Tone2(); Tone3();
  Tone3(); Tone3(); Tone2(); Tone2(); Tone1();
}

void ToneA() {
  Sound_Play( 880, 50);
}
void ToneC() {
  Sound_Play(1046, 50);
}
void ToneE() {
  Sound_Play(1318, 50);
}

void Melody2() {
  unsigned short i;
  for (i = 9; i > 0; i--) {
    ToneA(); ToneC(); ToneE();
  }
}

void main() {

  ADPCFG = 0x1C3F;                  // Configure AN pins as digital
  TRISB = 0xF8;                     // Configure RB7..RB3 as input
  LATB = 0;

  Sound_Init(&PORTB, 8);
  Sound_Play(880, 1000);            // Play sound at 880Hz for 1 second

  while (1) {
    if (Button(&PORTB,7,1,1))       // RB7 plays Tone1
      Tone1();
    while (RB7_bit);                // Wait for button to be released

    if (Button(&PORTB,6,1,1))       // RB6 plays Tone2
      Tone2();
    while (RB6_bit);                // Wait for button to be released

    if (Button(&PORTB,5,1,1))       // RB5 plays Tone3
      Tone3();
    while (RB5_bit);                // Wait for button to be released

    if (Button(&PORTB,4,1,1))       // RB4 plays Melody2
      Melody2();
    while (RB4_bit);                // Wait for button to be released

    if (Button(&PORTB,3,1,1))       // RB3 plays Melody
      Melody();
    while (RB4_bit);                // Wait for button to be released
  }
}