/*
 * Project name:
     Touch Sense (Touch Sense Demo)
 * Copyright:
     (c) mikroElektronika, 2011.
 * Revision History:
     20110202:
       - Initial release (SZ);
 * Description:
     A simple example of using the on-board Touch Sense feature.
     CAP buttons are being polled in an endless loop and the name of the pressed button is being displayed at the LCD.
 * Test configuration:
     MCU:             PIC24FJ16KA102
                      http://ww1.microchip.com/downloads/en/DeviceDoc/PIC24F16KA102_Family_datasheet_39927b.pdf
     Dev.Board:       Easy24-33 v6
                      http://www.mikroe.com/eng/products/view/494/easy24-33-v6-development-system/
     Oscillator:      HS-PLL, 32.00000 MHz
     Ext. Modules:    Character LCD 2x16
                      http://www.mikroe.com/en/tools/components/#other
     SW:              mikroC PRO for dsPIC30/33 and PIC24
                      http://www.mikroe.com/eng/products/view/231/mikroc-pro-for-dspic30-33-and-pic24/
 * NOTES:
      - Pull down the RA6 pin and set J6 to Vcc
      - Turn ON the LCD Backlight
      - Remove the pull-up(down) jumpers from the pins used in the Easy24-33v6 Touch Sense (RB0, RB1, RB2, RB12 and RB14)
      - All on-board switches with connections to Touch Sense pins must be disabled!
 */



#include "CAPSense.h"

// LCD module connections
sbit LCD_RS at LATB4_bit;
sbit LCD_EN at LATB5_bit;
sbit LCD_D4 at LATB6_bit;
sbit LCD_D5 at LATA0_bit;
sbit LCD_D6 at LATA1_bit;
sbit LCD_D7 at LATA4_bit;

sbit LCD_RS_Direction at TRISB4_bit;
sbit LCD_EN_Direction at TRISB5_bit;
sbit LCD_D4_Direction at TRISB6_bit;
sbit LCD_D5_Direction at TRISA0_bit;
sbit LCD_D6_Direction at TRISA1_bit;
sbit LCD_D7_Direction at TRISA4_bit;
// End LCD module connections


unsigned Read_Value[20], ref_value[20];
char txt[10], button, button_found;

void main(){
   AD1PCFG = 0x01CF;                  // Configure all pins as digital I/O
   TRISA6_bit = 1;
   
   Lcd_Init();                        // Initialize LCD
   Delay_ms(100);

   Lcd_Cmd(_LCD_CLEAR);               // Clear display
   Lcd_Cmd(_LCD_CURSOR_OFF);          // Cursor off

   CAPSense_Init();

   button = 255;
   Delay_ms(500);

// Calibration
   Lcd_Out(1,1,"  Calibration ");
   Delay_ms(1500);
   Lcd_Cmd(_LCD_CLEAR);               // Clear display


// During this calibration you can see watch the values measured by the ADC module on the LCD.
// Compare the values when the Touch(CAP) Sense button is pressed and when not pressed.
// Be sure to leave the calibration for each button (RA6 pin) with out the Touch Sense pressed.
// The unpressed values is what we need to store to ref_value!
   while(1){
   Lcd_Out(1,1,"UP      RA6-next");
   ref_value[_UP] = CAPSense_Read(_UP);
   Delay_ms(10);
   WordToStr(ref_value[_UP], txt);
   Lcd_Out(2,1,txt);
   Delay_ms(500);
   if(RA6_bit) break;
   Lcd_Cmd(_LCD_CLEAR);

  }

   while(1){
   Lcd_Out(1,1,"DOWN    RA6-next");
   ref_value[_DOWN] = CAPSense_Read(_DOWN);
   Delay_ms(10);
   WordToStr(ref_value[_DOWN], txt);
   Lcd_Out(2,1,txt);
   Delay_ms(500);
   if(RA6_bit) break;
   Lcd_Cmd(_LCD_CLEAR);
   }


   while(1){
   Lcd_Out(1,1,"RIGHT   RA6-next");
   ref_value[_RIGHT] = CAPSense_Read(_RIGHT);
   Delay_ms(10);
   WordToStr(ref_value[_RIGHT], txt);
   Lcd_Out(2,1,txt);
   Delay_ms(500);
   if(RA6_bit) break;
   Lcd_Cmd(_LCD_CLEAR);
  }


   while(1){
   Lcd_Out(1,1,"LEFT    RA6-next");
   ref_value[_LEFT] = CAPSense_Read(_LEFT);
   Delay_ms(10);
   WordToStr(ref_value[_LEFT], txt);
   Lcd_Out(2,1,txt);
   Delay_ms(500);
   if(RA6_bit) break;
   Lcd_Cmd(_LCD_CLEAR);
   }


   while(1){
   Lcd_Out(1,1,"E       RA6-next");
   ref_value[_E] = CAPSense_Read(_E);
   Delay_ms(10);
   WordToStr(ref_value[_E], txt);
   Lcd_Out(2,1,txt);
   Delay_ms(500);
   if(RA6_bit) break;
   Lcd_Cmd(_LCD_CLEAR);
   }


   while(1){
   Lcd_Out(1,1,"C       RA6-next");
   ref_value[_C] = CAPSense_Read(_C);
   Delay_ms(10);
   WordToStr(ref_value[_C], txt);
   Lcd_Out(2,1,txt);
   Delay_ms(500);
   if(RA6_bit) break;
   Lcd_Cmd(_LCD_CLEAR);

   }

//

// Now, it is time to set the ADC treshold values!
  ref_value[_UP] -= 30;
  ref_value[_LEFT] -= 50;
  ref_value[_RIGHT] -= 30;
  ref_value[_DOWN] -= 30;
  ref_value[_E] -= 30;
  ref_value[_C]-= 30;
//

  Lcd_Cmd(_LCD_CLEAR);
  Lcd_Out(1,1,"Calibration End!");
  Delay_ms(1500);
  Lcd_Cmd(_LCD_CLEAR);

while(1) {     // Polling the CAP buttons in an endless loop and displaying the name of the pressed button at the LCD!

    button = 255;
    Delay_ms(10);
    button_found = 0;

    Read_Value[_UP] = CAPSense_Read(_UP);
    Read_Value[_LEFT] = CAPSense_Read(_LEFT);
    Read_Value[_RIGHT] = CAPSense_Read(_RIGHT);
    Read_Value[_DOWN] = CAPSense_Read(_DOWN);
    Read_Value[_E] = CAPSense_Read(_E);
    Read_Value[_C] = CAPSense_Read(_C);


    if ((Read_Value[_UP] < ref_value[_UP]) && !button_found) {button = 0; button_found = 1;}
    if ((Read_Value[_DOWN] < ref_value[_DOWN]) && !button_found) {button = 1; button_found = 1;}
    if ((Read_Value[_RIGHT] < ref_value[_RIGHT]) && !button_found) {button = 3; button_found = 1;}
    if ((Read_Value[_LEFT] < ref_value[_LEFT]) && !button_found) {button = 4; button_found = 1;}
    if ((Read_Value[_E] < ref_value[_E]) && !button_found) {button = 5; button_found = 1;}
    if ((Read_Value[_C] < ref_value[_C]) && !button_found) {button = 12; button_found = 1;}


     if (!button_found) button = 255;

     switch (button) {

      case 0 :   { Lcd_Cmd(_LCD_CLEAR);
                   Lcd_Out(1,1,"       UP    ");
                   Delay_ms(500);
                   break;
                 }

      case 1 :  { Lcd_Cmd(_LCD_CLEAR);
                  Lcd_Out(2,1,"     DOWN    ");
                  Delay_ms(500);
                  break;
                 }

      case 3 :  { Lcd_Cmd(_LCD_CLEAR);
                  Lcd_Out(1,1,"     RIGHT ");
                  Delay_ms(500);
                  break;
                 }


      case 4 :  { Lcd_Cmd(_LCD_CLEAR);
                  Lcd_Out(1,1,"    LEFT    ");
                  Delay_ms(500);
                  break;
                 }

      case 5 :  { Lcd_Cmd(_LCD_CLEAR);
                  Lcd_Out(1,1,"   ENTER  ");
                  Delay_ms(500);
                  break;
                 }

      case 12 : { Lcd_Cmd(_LCD_CLEAR);
                  Lcd_Out(1,1,"     CLEAR   ");
                  Delay_ms(500);
                  break;
                 }
     default : {Lcd_Cmd(_LCD_CLEAR);
                Lcd_Out(1,1,"Hit any CAP key!");
                Delay_ms(500);
               }

     }
    Delay_ms(100);
 }
}